## 项目名称
> 设计文档: https://www.kdocs.cn/l/cvKBY8SqJoCC  
> Release Note: https://www.kdocs.cn/l/cvR7iKFqYQqY  
> 快速上手: https://www.kdocs.cn/l/caTTLzF7yoWF  
> 使用样例: example/*.py  

## Update repo

```shell
cd to modelbest_sdk dir

git submodule update --init --recursive
git submodule update --remote --recursive
git submodule foreach --recursive git checkout master
git submodule foreach --recursive git pull origin master

```
